==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_NumericalMathFunction_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_std.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *  Id:      $Id: t_NumericalMathFunction_std.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include <iostream>
#include <sstream>
#include <exception>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "NumericalMathFunction.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;
using namespace OT::Base::Func;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;

  try {

    // Test basic functionnalities
    //checkClassWithClassName<ComputedNumericalMathEvaluationImplementation>();

    // Test some extra functionnalities
    //checkNameFeature<ComputedNumericalMathEvaluationImplementation>();


    /** Instance creation */
    NumericalMathFunction myFunc("poutre");

    /** Copy constructor */
    NumericalMathFunction newFunc(myFunc);

    std::cout << "myFunc=" << myFunc << std::endl;
    std::cout << "myFunc input parameter(s)=";
    for (UnsignedLong i = 0; i < myFunc.getInputNumericalPointDimension(); i++)
      {
	std::cout << (i == 0? "":",") << myFunc.getInputDescription()[i];
      }
    std::cout << std::endl;
    std::cout << "myFunc output parameter(s)=";
    for (UnsignedLong i = 0; i < myFunc.getOutputNumericalPointDimension(); i++)
      {
	std::cout << (i == 0? "":",") << myFunc.getOutputDescription()[i];
      }
    std::cout << std::endl;
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_NumericalMathFunction_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_std.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_NumericalMathFunction_std.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include <iostream>
#include <sstream>
#include <exception>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "NumericalMathFunction.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Common;
using namespace OT::Base::Type;
using namespace OT::Base::Func;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try {

    // Test basic functionnalities
    //checkClassWithClassName<ComputedNumericalMathEvaluationImplementation>();

    // Test some extra functionnalities
    //checkNameFeature<ComputedNumericalMathEvaluationImplementation>();


    /** Instance creation */
    NumericalMathFunction myFunc("poutre");

    /** Copy constructor */
    NumericalMathFunction newFunc(myFunc);

    fullprint << "myFunc=" << myFunc << std::endl;
    fullprint << "myFunc input parameter(s)=";
    for (UnsignedLong i = 0; i < myFunc.getInputNumericalPointDimension(); i++)
      {
	fullprint << (i == 0? "":",") << myFunc.getInputDescription()[i];
      }
    fullprint << std::endl;
    fullprint << "myFunc output parameter(s)=";
    for (UnsignedLong i = 0; i < myFunc.getOutputNumericalPointDimension(); i++)
      {
	fullprint << (i == 0? "":",") << myFunc.getOutputDescription()[i];
      }
    fullprint << std::endl;
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
